package com.pj.biz;

import java.util.List;

import com.pj.project.tb_car_visit_record.TbCarVisitRecord;
import com.pj.project.tb_car_visit_record.TbCarVisitRecordService;
import com.pj.project.tb_person_visit_record.TbPersonVisitRecord;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.bind.annotation.*;

import com.pj.utils.sg.*;
import com.pj.utils.so.*;
import com.pj.project4sp.SP;

import com.pj.current.satoken.StpUserUtil;
import cn.dev33.satoken.annotation.SaCheckPermission;


/**
 * Controller: tb_car_visit_record -- 车辆出入记录
 *
 * @author qzyReal
 */
@RestController
@RequestMapping("/TbCarVisitRecord/")
public class TbCarVisitRecordController {

    /**
     * 底层 Service 对象
     */
    @Autowired
    TbCarVisitRecordService tbCarVisitRecordService;

    /**
     * 增
     */
    @RequestMapping("add")
    @SaCheckPermission(TbCarVisitRecord.PERMISSION_CODE_ADD)
    public AjaxJson add(TbCarVisitRecord t) {
        tbCarVisitRecordService.add(t);
        return AjaxJson.getSuccessData(t);
    }

    /**
     * 删
     */
    @RequestMapping("delete")
    @SaCheckPermission(TbCarVisitRecord.PERMISSION_CODE_DEL)
    public AjaxJson delete(Long id) {
        tbCarVisitRecordService.delete(id);
        return AjaxJson.getSuccess();
    }



    /**
     * 改
     */
    @RequestMapping("update")
    @SaCheckPermission(TbCarVisitRecord.PERMISSION_CODE_EDIT)
    public AjaxJson update(TbCarVisitRecord t) {
        tbCarVisitRecordService.update(t);
        return AjaxJson.getSuccess();
    }

    /**
     * 查 - 根据id
     */
    @RequestMapping("getById")
    public AjaxJson getById(Long id) {
        TbCarVisitRecord t = tbCarVisitRecordService.getById(id);
        return AjaxJson.getSuccessData(t);
    }

    /**
     * 查集合 - 根据条件（参数为空时代表忽略指定条件）
     */
    @RequestMapping("getList")
    public AjaxJson getList() {
        SoMap so = SoMap.getRequestSoMap();
        List<TbCarVisitRecord> list = tbCarVisitRecordService.getList(so.startPage());
        return AjaxJson.getPageData(so.getDataCount(), list);
    }

    @RequestMapping("export")
    @SaCheckPermission(TbCarVisitRecord.PERMISSION_CODE_EXPORT)
    public AjaxJson export() {
        SoMap soMap = SoMap.getRequestSoMap();
        return AjaxJson.getSuccessData(tbCarVisitRecordService.export(soMap));
    }
}
