package com.pj.biz;

import java.util.List;

import com.pj.current.satoken.StpUserUtil;
import com.pj.project.tb_car_filing.TbCarFiling;
import com.pj.project.tb_car_filing.TbCarFilingService;
import com.pj.project4sp.SP;
import com.pj.utils.sg.AjaxJson;
import com.pj.utils.so.SoMap;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.bind.annotation.*;

import cn.dev33.satoken.annotation.SaCheckPermission;


/**
 * Controller: tb_car_filing -- 车辆备案
 *
 * @author qzyReal
 */
@RestController
@RequestMapping("/TbCarFiling/")
public class TbCarFilingController {

    /**
     * 底层 Service 对象
     */
    @Autowired
    TbCarFilingService tbCarFilingService;

    /**
     * 增
     */
    @RequestMapping("add")
    @SaCheckPermission(TbCarFiling.PERMISSION_CODE_ADD)
    @Transactional(rollbackFor = Exception.class)
    public AjaxJson add(TbCarFiling t) {
        tbCarFilingService.add(t);
        return AjaxJson.getSuccessData(t);
    }

    /**
     * 删
     */
    @RequestMapping("delete")
    @SaCheckPermission(TbCarFiling.PERMISSION_CODE_DEL)
    public AjaxJson delete(Long id) {
        tbCarFilingService.delete(id);
        return AjaxJson.getSuccess();
    }

    /**
     * 删 - 根据id列表
     */
    @RequestMapping("deleteByIds")
    @SaCheckPermission(TbCarFiling.PERMISSION_CODE_DEL)
    public AjaxJson deleteByIds() {
        List<Long> ids = SoMap.getRequestSoMap().getListByComma("ids", long.class);
        int line = SP.publicMapper.deleteByIds(TbCarFiling.TABLE_NAME, ids);
        return AjaxJson.getByLine(line);
    }

    /**
     * 改
     */
    @RequestMapping("update")
    @SaCheckPermission(TbCarFiling.PERMISSION_CODE_DEL)
    public AjaxJson update(TbCarFiling t) {
        tbCarFilingService.update(t);
        return AjaxJson.getSuccess();
    }

    /**
     * 查 - 根据id
     */
    @RequestMapping("getById")
    public AjaxJson getById(Long id) {
        TbCarFiling t = tbCarFilingService.getById(id);
        return AjaxJson.getSuccessData(t);
    }

    /**
     * 查集合 - 根据条件（参数为空时代表忽略指定条件）
     */
    @RequestMapping("getList")
    public AjaxJson getList() {
        SoMap so = SoMap.getRequestSoMap();
        long deptId = StpUserUtil.getDeptId();
        if (deptId != StpUserUtil.ADMIN_DEPT_ID) {
            so.put("deptId", deptId);
        }
        List<TbCarFiling> list = tbCarFilingService.getList(so.startPage());
        return AjaxJson.getPageData(so.getDataCount(), list);
    }


}
