package com.pj.current.netty.command.handler.impl;

import cn.hutool.core.util.RandomUtil;
import cn.hutool.json.JSONObject;
import cn.hutool.json.JSONUtil;
import com.pj.current.netty.command.constants.CommandType;
import com.pj.current.netty.command.handler.IHandler;
import com.pj.current.netty.command.handler.dto.ChecklogDTO;
import com.pj.current.netty.dto.OKMsg;
import com.pj.current.netty.dto.RequestPackageDTO;
import com.pj.current.task.TaskService;
import com.pj.project.tb_dept.TbDept;
import com.pj.project.tb_dept.TbDeptService;
import com.pj.project.tb_person_filing.TbPersonFiling;
import com.pj.project.tb_person_filing.TbPersonFilingService;
import com.pj.project.tb_person_visit_record.TbPersonVisitRecord;
import com.pj.project.tb_person_visit_record.TbPersonVisitRecordService;
import com.pj.project.tb_person_visit_record.task.ConvertBase64ToImage;
import com.pj.project.tb_terminal.TbTerminal;
import com.pj.project.tb_terminal.TbTerminalService;
import io.netty.channel.ChannelHandlerContext;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.time.LocalDateTime;
import java.time.ZoneId;
import java.util.Date;

/**
 * 人脸核验记录
 */
@Service
@Slf4j
public class CheckLogHandler implements IHandler {

    @Resource
    private TbPersonVisitRecordService tbPersonVisitRecordService;
    @Resource
    private TbTerminalService tbTerminalService;
    @Resource
    private TbPersonFilingService tbPersonFilingService;
    @Resource
    private TaskService taskService;
    @Resource
    private TbDeptService tbDeptService;

    @Override
    public CommandType commandType() {
        return CommandType.UPLOAD_CHECK_LOG;
    }

    @Override
    public void handler(ChannelHandlerContext ctx, RequestPackageDTO packageDTO) {
        log.info("============核验记录上传========:{}", JSONUtil.toJsonStr(packageDTO));
        JSONObject params = JSONUtil.parseObj(packageDTO.getPayload().getParams());
        String str = params.getStr("log");
        ChecklogDTO dto = JSONUtil.toBean(str, ChecklogDTO.class);

        String sn = params.getStr("sn");
        TbTerminal tbTerminal = tbTerminalService.findBySN(sn);
        Long deptId = tbTerminal.getDeptId();
        TbDept tbDept = tbDeptService.getById(deptId);
        Date date = dto.getDate();
        LocalDateTime dayTime = date.toInstant().atZone(ZoneId.systemDefault()).toLocalDateTime();
        Integer direction = dto.getDirection();
        TbPersonFiling tbPersonFiling = tbPersonFilingService.findByPin(dto.getPin());
        String idCard = tbPersonFiling.getIdCard();
        TbPersonVisitRecord record = tbPersonVisitRecordService.findTheNearRecord(idCard, deptId, direction, dayTime.minusSeconds(8));
        if (record == null) {
            record = new TbPersonVisitRecord();
        }
        record.setDeptId(tbTerminal.getDeptId()).setType(TbPersonVisitRecord.TypeEnum.UPLOAD.getType())
                .setVenues(tbTerminal.getVenuesName()).setChannel(tbTerminal.getChannelName())
                .setTerminalName(tbTerminal.getName()).setVisitDate(dto.getDate()).setCreateTime(new Date())
                .setSn(sn).setUpdateTime(new Date()).setAllowPass(dto.isAllow_through())
                .setDirection(dto.getDirection()).setTemperature(dto.getTemperature()).setDeptName(tbDept.getName())
                .setName(tbPersonFiling.getName()).setPhone(tbPersonFiling.getPhone()).setIdCard(tbPersonFiling.getIdCard());
        tbPersonVisitRecordService.saveOrUpdate(record);
        ctx.write(OKMsg.ok());
        ctx.flush();
        taskService.addTask(new ConvertBase64ToImage(RandomUtil.randomNumbers(8), 2000, record.getId(), dto.getPicture()));
    }
}
