package com.pj.current.netty.command.handler.impl;

import cn.hutool.core.util.RandomUtil;
import cn.hutool.core.util.StrUtil;
import cn.hutool.json.JSONUtil;
import com.pj.current.config.MyConfig;
import com.pj.current.netty.command.constants.CommandType;
import com.pj.current.netty.command.handler.IHandler;
import com.pj.current.netty.dto.RequestPackageDTO;
import com.pj.current.task.TaskService;
import com.pj.project.tb_terminal.task.CommandDelayTask;
import com.pj.utils.cache.RedisUtil;
import io.netty.channel.ChannelHandlerContext;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.List;

/**
 * 设备请求下发命令
 */
@Service
@Slf4j
public class UploadCommandHandler implements IHandler {
    @Resource
    private MyConfig myConfig;
    @Resource
    private TaskService taskService;

    @Override
    public CommandType commandType() {
        return CommandType.UPLOAD_COMMAND;
    }

    @Override
    public void handler(ChannelHandlerContext ctx, RequestPackageDTO packageDTO) {
        log.info("进入请求命令处理========================");
        String sn = JSONUtil.parseObj(packageDTO.getPayload().getParams()).getStr("sn");
        String key = myConfig.getCommandPrefix() + sn;
        String commandListStr = RedisUtil.get(key);
        List<String> list = JSONUtil.toList(commandListStr, String.class);
        long delay = Long.parseLong(RandomUtil.randomNumbers(3));
        for (String command : list) {
            RequestPackageDTO requestPackageDTO = JSONUtil.toBean(command, RequestPackageDTO.class);
            String taskId=RandomUtil.randomNumbers(16);
            String msgId=requestPackageDTO.getMsgId();
            taskService.addTask(new CommandDelayTask(taskId, delay, ctx, command,msgId));
            delay = delay + 1000;
        }
        RedisUtil.del(key);
    }
}
