package com.pj.project.tb_dept;

import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.bind.annotation.*;

import com.pj.utils.sg.*;
import com.pj.utils.so.*;
import com.pj.project4sp.SP;

import com.pj.current.satoken.StpUserUtil;
import cn.dev33.satoken.annotation.SaCheckPermission;


/**
 * Controller: tb_dept -- 组织管理
 *
 * @author qzyReal
 */
@RestController
@RequestMapping("/TbDept/")
public class TbDeptController {

    /**
     * 底层 Service 对象
     */
    @Autowired
    TbDeptService tbDeptService;

    /**
     * 增
     */
    @RequestMapping("add")
    @SaCheckPermission(TbDept.PERMISSION_CODE_ADD)
    @Transactional(rollbackFor = Exception.class)
    public AjaxJson add(TbDept t) {
        tbDeptService.add(t);
        return AjaxJson.getSuccessData(t);
    }

    /**
     * 删
     */
    @RequestMapping("delete")
    @SaCheckPermission(TbDept.PERMISSION_CODE_DEL)
    public AjaxJson delete(Long id) {
        tbDeptService.delete(id);
        return AjaxJson.getSuccess();
    }

    /**
     * 删 - 根据id列表
     */
    @RequestMapping("deleteByIds")
    @SaCheckPermission(TbDept.PERMISSION_CODE_DEL)
    public AjaxJson deleteByIds() {
        List<Long> ids = SoMap.getRequestSoMap().getListByComma("ids", long.class);
        int line = SP.publicMapper.deleteByIds(TbDept.TABLE_NAME, ids);
        return AjaxJson.getByLine(line);
    }

    /**
     * 改
     */
    @RequestMapping("update")
    @SaCheckPermission(TbDept.PERMISSION_CODE_EDIT)
    public AjaxJson update(TbDept t) {
        tbDeptService.update(t);
        return AjaxJson.getSuccess();
    }

    /**
     * 查 - 根据id
     */
    @RequestMapping("getById")
    public AjaxJson getById(Long id) {
        TbDept t = tbDeptService.getById(id);
        return AjaxJson.getSuccessData(t);
    }

    /**
     * 查集合 - 根据条件（参数为空时代表忽略指定条件）
     */
    @RequestMapping("getList")
    public AjaxJson getList() {
        SoMap so = SoMap.getRequestSoMap();
        long deptId = StpUserUtil.getDeptId();
        if (StpUserUtil.ADMIN_DEPT_ID != deptId) {
            so.put("id", deptId);
        }
        List<TbDept> list = tbDeptService.getList(so.startPage());
        return AjaxJson.getPageData(so.getDataCount(), list);
    }


}
