package com.pj.project.tb_person_visit_record;

import java.io.File;
import java.time.LocalDateTime;
import java.time.format.DateTimeFormatter;
import java.util.Date;
import java.util.List;

import cn.dev33.satoken.stp.StpUtil;
import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.date.DateUtil;
import cn.hutool.core.io.FileUtil;
import cn.hutool.core.util.RandomUtil;
import cn.hutool.core.util.StrUtil;
import cn.hutool.poi.excel.ExcelUtil;
import cn.hutool.poi.excel.ExcelWriter;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.service.IService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.pj.current.config.SystemObject;
import com.pj.current.global.BusinessException;
import com.pj.project.tb_venues.TbVenues;
import com.pj.project.tb_venues.TbVenuesService;
import com.pj.project4sp.uploadfile.UploadConfig;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.pj.utils.so.*;

import javax.annotation.Resource;

/**
 * Service: tb_person_visit_record -- 人员出入记录
 *
 * @author qzyReal
 */
@Service
@Transactional(rollbackFor = Exception.class)
public class TbPersonVisitRecordService extends ServiceImpl<TbPersonVisitRecordMapper, TbPersonVisitRecord> implements IService<TbPersonVisitRecord> {

    /**
     * 底层 Mapper 对象
     */
    @Autowired
    TbPersonVisitRecordMapper tbPersonVisitRecordMapper;
    @Resource
    private UploadConfig uploadConfig;
    @Resource
    private TbVenuesService tbVenuesService;


    /**
     * 增
     */
    public void add(VisitAddBO t) {
        String inChannel = t.getInChannel();
        String outChannel = t.getOutChannel();
        if (StrUtil.isEmpty(inChannel) && StrUtil.isEmpty(outChannel)) {
            throw new BusinessException("缺少出入场信息");
        }
        if (StrUtil.isNotEmpty(inChannel)) {
            handler(t, TbPersonVisitRecord.DirectionEnum.IN.getDirection(), inChannel);
        }
        if (StrUtil.isNotEmpty(outChannel)) {
            handler(t, TbPersonVisitRecord.DirectionEnum.OUT.getDirection(), outChannel);
        }
    }

    private void handler(VisitAddBO t, Integer direction, String channelId) {
        Date now = new Date();
        TbPersonVisitRecord record = new TbPersonVisitRecord();
        record.setType(TbPersonVisitRecord.TypeEnum.ADD.getType())
                .setCreateTime(now).setUpdateTime(now).setDirection(direction);
        BeanUtil.copyProperties(t, record);
        TbVenues tbVenues = tbVenuesService.getById(channelId);
        record.setChannel(channelId).setVenues(tbVenues.getName()).setDeptId(tbVenues.getDeptId()).setDeptName(tbVenues.getDeptName());
        if (direction.equals(TbPersonVisitRecord.DirectionEnum.IN.getDirection())) {
            record.setVisitDate(t.getInTime())
                    .setTemperature(t.getInTemperature());
        } else if (direction.equals(TbPersonVisitRecord.DirectionEnum.OUT.getDirection())) {
            record.setVisitDate(t.getOutTime()).setTemperature(t.getOutTemperature());
        }
        this.save(record);
    }

    /**
     * 删
     */
    public void delete(Long id) {
        this.removeById(id);
    }

    /**
     * 改
     */
    public void update(TbPersonVisitRecord t) {
        this.updateById(t);
    }

    /**
     * 查
     */
    public TbPersonVisitRecord getById(Long id) {
        return super.getById(id);
    }

    /**
     * 查集合 - 根据条件（参数为空时代表忽略指定条件）
     */
    public List<TbPersonVisitRecord> getList(SoMap so) {
        return tbPersonVisitRecordMapper.getList(so);
    }


    public String export(SoMap soMap) {
        List<TbPersonVisitRecord> list = tbPersonVisitRecordMapper.getList(soMap);
        String flieTypeFolder = "/export/";
        String currDateFolder = DateUtil.today();
        String fileName = "record-" + DateUtil.format(new Date(), "yyyyMMddHHmmss") + ".xlsx";
        String fileFolder = new File(uploadConfig.rootFolder).getAbsolutePath() +
                uploadConfig.httpPrefix + flieTypeFolder + currDateFolder + "/";
        if (!FileUtil.exist(fileFolder)) {
            FileUtil.mkdir(fileFolder);
        }
        ExcelWriter writer = ExcelUtil.getWriter(fileFolder + fileName);
        writer.addHeaderAlias("name", "姓名");
        writer.addHeaderAlias("deptName", "部门");
        writer.addHeaderAlias("idCard", "身份证");
        writer.addHeaderAlias("venues", "场所");
        writer.addHeaderAlias("channel", "通道");
        writer.addHeaderAlias("temperature", "体温");
        writer.addHeaderAlias("healthStatus", "健康码");
        writer.addHeaderAlias("visitDate", "时间");
        writer.addHeaderAlias("terminalName", "识别设备");
        writer.addHeaderAlias("typeStr", "补录/自动");
        writer.addHeaderAlias("directionStr", "入场/离场");
        writer.setOnlyAlias(true);
        writer.write(list, true);
        writer.close();
        return SystemObject.config.getDomain() + uploadConfig.httpPrefix + flieTypeFolder + currDateFolder + "/" + fileName;
    }

    public TbPersonVisitRecord findTheNearRecord(String idCard, Long deptId, Integer direction, LocalDateTime checkDate) {
        QueryWrapper<TbPersonVisitRecord> ew = new QueryWrapper<>();
        ew.eq("dept_id", deptId)
                .eq("id_card", idCard)
                .eq("direction", direction)
                .ge("date_format(visit_date,'%Y-%m-%d %H:%i:%s')", checkDate.format(DateTimeFormatter.ofPattern("yyyy-MM-dd HH:mm:ss")));
        ew.orderByDesc("id");
        List<TbPersonVisitRecord> list = list(ew);
        return list.isEmpty() ? null : list.get(0);
    }
}
