package com.pj.project.tb_venues;

import java.util.Date;
import java.util.List;

import cn.dev33.satoken.stp.StpUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.service.IService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.pj.current.global.BusinessException;
import com.pj.project.tb_dept.TbDept;
import com.pj.project.tb_dept.TbDeptService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.pj.utils.so.*;

import javax.annotation.Resource;

/**
 * Service: tb_venues -- 场所管理
 *
 * @author qzyReal
 */
@Service
@Transactional(rollbackFor = Exception.class)
public class TbVenuesService extends ServiceImpl<TbVenuesMapper, TbVenues> implements IService<TbVenues> {

    /**
     * 底层 Mapper 对象
     */
    @Autowired
    TbVenuesMapper tbVenuesMapper;
    @Resource
    private TbDeptService tbDeptService;

    /**
     * 增
     */
    public void add(TbVenues t) {
        t.setCreateBy(StpUtil.getLoginIdAsString()).setCreateTime(new Date());
        handler(t);
        this.save(t);
    }

    private void handler(TbVenues t) {
        TbDept tbDept = tbDeptService.getById(t.getDeptId());
        t.setDeptName(tbDept.getName()).setUpdateBy(StpUtil.getLoginIdAsString()).setUpdateTime(new Date());
    }

    /**
     * 删
     */
    public void delete(Long id) {
        List<TbVenues> list = this.findByPid(id);
        if (!list.isEmpty()){
            throw new BusinessException("该场所存在通道，不能删除");
        }
        this.removeById(id);
    }

    private List<TbVenues> findByPid(Long id) {
        QueryWrapper<TbVenues>ew=new QueryWrapper<>();
        ew.eq("p_id",id);
        return list(ew);
    }

    /**
     * 改
     */
    public void update(TbVenues t) {
        t.setUpdateBy(StpUtil.getLoginIdAsString()).setUpdateTime(new Date());
        this.updateById(t);
    }

    /**
     * 查
     */
    public TbVenues getById(Long id) {
        return super.getById(id);
    }

    /**
     * 查集合 - 根据条件（参数为空时代表忽略指定条件）
     */
    public List<TbVenues> getList(SoMap so) {
        return tbVenuesMapper.getList(so);
    }


}
